<?php
namespace Concrete\Package\DatabaseDumper\Database;

use Concrete\Package\DatabaseDumper\ApplicationTrait;
use Concrete\Package\DatabaseDumper\Database\Connection\Connection;

class ConnectionFactory
{
    private $connection;

    use ApplicationTrait;

    /**
     * @return Connection
     */
    public function connection()
    {
        if (!$this->connection) {
            $this->connection = $this->createConnection();
        }

        return $this->connection;
    }

    private function createConnection()
    {
        $config = $this->getConfig();

        $c = new Connection($config['driver']);
        $host = $config['server'];
        if (isset($config['port'])) {
            $host .= ':' . $config['port'];
        }

        if ($c->connect($host, $config['username'], $config['password'], $config['database'])) {
            return $c;
        }

        $e = $c->error;
        if (function_exists('iconv') && strlen($pf = iconv("windows-1250", "utf-8", $e)) > strlen($e)) {
            $e = $pf;
        }

        return $e;
    }

    protected function getConfig()
    {
        $config = $this->app('config');
        $defaultConnection = $config['database.default-connection'];

        return $config['database.connections'][$defaultConnection];
    }
}
